==> haskell-doctemplates-0.11.0.1-68.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctemplates
version:              0.11.0.1
visibility:           public
id:                   doctemplates-0.11.0.1-4C1WX7z3ar72eiZn8lfdV0
key:                  doctemplates-0.11.0.1-4C1WX7z3ar72eiZn8lfdV0
license:              BSD-3-Clause
copyright:            2016-19 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doctemplates#readme
synopsis:             Pandoc-style document templates
description:
    This is the text templating system used by pandoc.
    It supports variable interpolation, iteration,
    tests for non-blank values, pipes, and partials.
    Templates are rendered to doclayout Docs,
    and variable values may come from a variety of
    different sources, including aeson Values.

category:             Text
abi:                  d2b19722cae5ff9f4b5b4316c2af71b0
exposed:              True
exposed-modules:
    Text.DocTemplates Text.DocTemplates.Internal
    Text.DocTemplates.Parser

import-dirs:          /usr/lib/ghc-9.6.6/site-local/doctemplates-0.11.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/doctemplates-0.11.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/doctemplates-0.11.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctemplates
hs-libraries:         HSdoctemplates-0.11.0.1-4C1WX7z3ar72eiZn8lfdV0
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1 containers-0.6.7
    doclayout-0.5-G2Wm2VuIsgJ2QywWYn7p6r filepath-1.4.300.1 mtl-2.3.1
    parsec-3.1.16.1 safe-0.3.21-6ywRAlXnRFuBscoqJeUz3o
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV text-2.0.2
    text-conversions-0.3.1.1-K1Yt8b0G42m5WYfZmJLFVT
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock

haddock-html:         /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctemplates-0.11.0.1-69-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctemplates
version:              0.11.0.1
visibility:           public
id:                   doctemplates-0.11.0.1-FbE5pAm9pT9IYBZ2Oe97Y2
key:                  doctemplates-0.11.0.1-FbE5pAm9pT9IYBZ2Oe97Y2
license:              BSD-3-Clause
copyright:            2016-19 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doctemplates#readme
synopsis:             Pandoc-style document templates
description:
    This is the text templating system used by pandoc.
    It supports variable interpolation, iteration,
    tests for non-blank values, pipes, and partials.
    Templates are rendered to doclayout Docs,
    and variable values may come from a variety of
    different sources, including aeson Values.

category:             Text
abi:                  5aaee3125250325432df31556ccb1d05
exposed:              True
exposed-modules:
    Text.DocTemplates Text.DocTemplates.Internal
    Text.DocTemplates.Parser

import-dirs:          /usr/lib/ghc-9.6.6/site-local/doctemplates-0.11.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/doctemplates-0.11.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/doctemplates-0.11.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctemplates
hs-libraries:         HSdoctemplates-0.11.0.1-FbE5pAm9pT9IYBZ2Oe97Y2
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1 containers-0.6.7
    doclayout-0.5-9EZxKgaNTpvH3oLmqoAtl2 filepath-1.4.300.1 mtl-2.3.1
    parsec-3.1.16.1 safe-0.3.21-7oQO4KcgDWt1YhK3ifcAwa
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW text-2.0.2
    text-conversions-0.3.1.1-FiAyQC2JfI11GT7GIwm2Pu
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock

haddock-html:         /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
